/* eslint-disable */

module.exports = {
	env: {
		browser: true,
		es2021: true,
	},
	extends: [
		'eslint:recommended',
		'plugin:@typescript-eslint/recommended',
		'plugin:react/recommended',
	],
	settings: {
		react: {
			version: 'detect',
		},
	},
	overrides: [
		{
			env: {
				node: true,
			},
			files: ['.eslintrc.{js,cjs}'],
			parserOptions: {
				sourceType: 'script',
			},
		},
	],
	parser: '@typescript-eslint/parser',
	parserOptions: {
		ecmaVersion: 'latest',
		sourceType: 'module',
	},
	plugins: ['@typescript-eslint', 'react', 'header', 'import'],
	rules: {
		'no-prototype-builtins': 'off',
		'prefer-template': 'warn',
		'no-multiple-empty-lines': ['warn', { 'max': 1 }],
		'space-infix-ops': ['warn', { 'int32Hint': false }],
		'max-len': ['warn', { 'code': 200 }],
		'@typescript-eslint/no-explicit-any': 'off',
		'no-useless-escape' : 'off',
		'@typescript-eslint/no-unused-vars': 'warn',
		'no-mixed-spaces-and-tabs': 'off',
		'import/first': 'warn',
		'react/destructuring-assignment': [
			'warn',
			'always',
			{
				'ignoreClassFields': true,
			},
		],
		'import/order': [
			'warn',
			{
				'groups': [
					['builtin', 'external'],
					['internal', 'parent', 'sibling'],
					'index',
					'object',
				],
				'newlines-between': 'always',
				'alphabetize': { order: 'asc', caseInsensitive: true },
			},
		],
		'no-magic-numbers': ['warn', { ignore: [0, 1, -1] }],
		'comma-dangle': ['warn', {
			'arrays': 'always-multiline',
			'objects': 'always-multiline',
			'imports': 'always-multiline',
			'exports': 'always-multiline',
			'functions': 'always-multiline',
		}],
		'@typescript-eslint/ban-ts-comment': [
			'warn',
			{
				'ts-expect-error': false,
				'ts-ignore': true,
				'ts-nocheck': true,
				'ts-check': false,
				minimumDescriptionLength: 3,
			},
		],
		'indent': ['warn', 'tab'],
		'no-console': 'warn',
		'header/header': [
			2,
			'block',
			[
				'',
				' * Copyright 2023 Mubasher Financial Services (DIFC) Limited. All rights reserved.',
				' *',
				' * Unauthorized access, copying, publishing, sharing, reuse of algorithms, concepts, design patterns',
				' * and code level demonstrations are strictly prohibited without any written approval of',
				' * Mubasher Financial Services (DIFC) Limited.',
				'',
			],
		],
		'spaced-comment': ['warn', 'always', { markers: ['*'] }],
		'react/react-in-jsx-scope': 'off',
		'react/prop-types': 'off',
		'quotes': ['warn', 'single'],
		'semi': ['warn', 'always'],
	},
};